pub struct ControlDefinition {
pub id: &'static str,
pub label: &'static str,
pub docs: &'static str,
pub kind: ControlKind,
}Fields
id: &'static strlabel: &'static strdocs: &'static strkind: ControlKindImplementations
Sourceimpl ControlDefinition
impl ControlDefinition
Sourcepub fn validate(&self, value: &ControlValue) -> Result<(), ControlError>
pub fn validate(&self, value: &ControlValue) -> Result<(), ControlError>
Validates metadata-level constraints before a typed field accepts a value.
Errors
Returns an error when a numeric value violates configured bounds or step.