FixtureDefinition

Struct FixtureDefinition 

pub struct FixtureDefinition<Renderer> { /* private fields */ }

Implementations

Source

impl<Renderer> FixtureDefinition<Renderer>

pub const fn metadata(&self) -> &FixtureMetadata

pub fn props(&self) -> &dyn HblankProps

pub const fn renderer(&self) -> &Renderer

pub fn default_control_value(&self, id: &str) -> Option<ControlValue>

pub fn apply_control_values<'a>( &mut self, values: impl IntoIterator<Item = (&'a str, &'a ControlValue)>, ) -> usize

Applies valid control values and ignores stale or invalid entries.

Returns the number of values accepted by this fixture.

pub fn set_control( &mut self, id: &str, value: ControlValue, ) -> Result<(), ControlError>

Replaces one generated property control value.

Errors

Returns an error when the identifier or value is invalid for this fixture’s props.

pub fn reset(&mut self)